@@ -1,22 +1,23 @@
 /*
 
-Copyright (C) 2012 Michael Goffioul.
-Copyright (C) 2012 Jacob Dawid.
+Copyright (C) 2012-2015 Michael Goffioul.
+Copyright (C) 2012-2015 Jacob Dawid.
 
 This file is part of QTerminal.
 
-Foobar is free software: you can redistribute it and/or modify
+This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
-QTerminal is distributed in the hope that it will be useful,
+This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
+along with this program.  If not,
+see <http://www.gnu.org/licenses/>.
 
 */
 
@@ -70,6 +71,17 @@ QTerminal::color_names (void)
   return names;
 }
 
+// slot for disabling the interrupt action when terminal loses focus
+void
+QTerminal::set_global_shortcuts (bool focus_out)
+  {
+    if (focus_out)
+      _interrupt_action->setShortcut (QKeySequence ());
+    else
+     _interrupt_action->setShortcut (
+              QKeySequence (Qt::ControlModifier + Qt::Key_C));
+  }
+
 void
 QTerminal::notice_settings (const QSettings *settings)
 {
@@ -77,11 +89,10 @@ QTerminal::notice_settings (const QSettings *settings)
 
   // Set terminal font:
   QFont term_font = QFont ();
+  term_font.setStyleHint (QFont::TypeWriter);
   term_font.setFamily
     (settings->value ("terminal/fontName", "Courier New").toString ());
-
   term_font.setPointSize (settings->value ("terminal/fontSize", 10).toInt ());
-
   setTerminalFont (term_font);
 
   QString cursorType
@@ -118,4 +129,26 @@ QTerminal::notice_settings (const QSettings *settings)
     (cursorUseForegroundColor,
      settings->value ("terminal/color_c",
                       QVariant (colors.at (3))).value<QColor> ());
+  setScrollBufferSize (settings->value ("terminal/history_buffer",1000).toInt () );
+
+  // check whether Copy shoretcut is Ctrl-C
+  int set = settings->value ("shortcuts/set",0).toInt ();
+  QKeySequence copy;
+  QString key = QString ("shortcuts/main_edit:copy");
+  if (set)
+    key.append ("_1");  // if second set is active
+  copy = QKeySequence (settings->value (key).toString ()); // the copy shortcut
+
+  // if copy is empty, shortcuts are not yet in the settings (take the default)
+  if (copy.isEmpty ())         // QKeySequence::Copy as second argument in
+    copy = QKeySequence::Copy; // settings->value () does not work!
+
+  //  dis- or enable extra interrupt action
+  QKeySequence ctrl;
+  ctrl = Qt::ControlModifier;
+
+  bool extra_ir_action = (copy != QKeySequence (ctrl + Qt::Key_C));
+
+  _interrupt_action->setEnabled (extra_ir_action);
+  has_extra_interrupt (extra_ir_action);
 }
