@@ -1,5 +1,5 @@
 /*  Copyright (C) 2008 e_k (e_k@users.sourceforge.net)
-    Copyright (C) 2012 Jacob Dawid <jacob.dawid@googlemail.com>
+    Copyright (C) 2012-2015 Jacob Dawid <jacob.dawid@cybercatalyst.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -46,6 +46,9 @@ void QUnixTerminalImpl::initialize()
     connect(m_terminalView, SIGNAL(customContextMenuRequested(QPoint)),
             this, SLOT(handleCustomContextMenuRequested(QPoint)));
 
+    connect (m_terminalView, SIGNAL (interrupt_signal (void)),
+             this, SLOT (terminal_interrupt ()));
+
 #ifdef Q_OS_MAC
     QFont font = QFont("Monaco");
     font.setStyleHint(QFont::TypeWriter);
@@ -56,6 +59,7 @@ void QUnixTerminalImpl::initialize()
     font.setPointSize(10);
 #endif
     setTerminalFont(font);
+    setFocusPolicy (Qt::StrongFocus);
     setFocusProxy(m_terminalView);
     setFocus(Qt::OtherFocusReason);
 
@@ -65,13 +69,23 @@ void QUnixTerminalImpl::initialize()
     m_terminalModel = new TerminalModel(m_kpty);
     m_terminalModel->setAutoClose(true);
     m_terminalModel->setCodec(QTextCodec::codecForName("UTF-8"));
-    m_terminalModel->setHistoryType(HistoryTypeBuffer(1000));
+    m_terminalModel->setHistoryType(HistoryTypeBuffer (1000));
     m_terminalModel->setDarkBackground(true);
     m_terminalModel->setKeyBindings("");
     m_terminalModel->run();
     m_terminalModel->addView(m_terminalView);
     connectToPty();
 }
+void QUnixTerminalImpl::setScrollBufferSize(int value)
+{
+  if (value > 0)
+    {
+      m_terminalModel->clearHistory ();
+      m_terminalModel->setHistoryType (HistoryTypeBuffer ( value ));
+    }
+  else
+    m_terminalModel->setHistoryType (HistoryTypeNone ());
+}
 
 void QUnixTerminalImpl::connectToPty()
 {
@@ -137,8 +151,8 @@ void QUnixTerminalImpl::setCursorType(CursorType type, bool blinking)
 
 // FIXME -- not sure how to make these work properly given the way the
 // Unix terminal handles colors.
-void QUnixTerminalImpl::setBackgroundColor (const QColor& color) 
-  { 
+void QUnixTerminalImpl::setBackgroundColor (const QColor& color)
+  {
     ColorEntry cols[TABLE_COLORS];
 
     const ColorEntry * curr_cols = m_terminalView->colorTable();
@@ -193,7 +207,7 @@ void QUnixTerminalImpl::resizeEvent(QResizeEvent*)
 
 void QUnixTerminalImpl::copyClipboard()
 {
-    m_terminalView->copyClipboard();
+    m_terminalView->copyClipboard (_extra_interrupt);
 }
 
 void QUnixTerminalImpl::pasteClipboard()
@@ -201,7 +215,19 @@ void QUnixTerminalImpl::pasteClipboard()
     m_terminalView->pasteClipboard();
 }
 
+void QUnixTerminalImpl::selectAll()
+{
+    m_terminalView->selectAll();
+}
+
+
 QString QUnixTerminalImpl::selectedText ()
 {
   return m_terminalView->selectedText ();
 }
+
+void
+QUnixTerminalImpl::has_extra_interrupt (bool extra)
+{
+  _extra_interrupt = extra;
+}
