@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1993-2012 John W. Eaton
+Copyright (C) 1993-2015 John W. Eaton
 Copyright (C) 2009-2010 VZLU Prague
 
 This file is part of Octave.
@@ -37,9 +37,11 @@ along with Octave; see the file COPYING.  If not, see
 #include "variables.h"
 
 DEFUN (abs, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} abs (@var{z})\n\
-Compute the magnitude of @var{z}, defined as\n\
+Compute the magnitude of @var{z}.\n\
+\n\
+The magnitude is defined as\n\
 @tex\n\
 $|z| = \\sqrt{x^2 + y^2}$.\n\
 @end tex\n\
@@ -55,6 +57,7 @@ abs (3 + 4i)\n\
      @result{} 5\n\
 @end group\n\
 @end example\n\
+@seealso{arg}\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -84,7 +87,7 @@ abs (3 + 4i)\n\
 */
 
 DEFUN (acos, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} acos (@var{x})\n\
 Compute the inverse cosine in radians for each element of @var{x}.\n\
 @seealso{cos, acosd}\n\
@@ -114,12 +117,26 @@ Compute the inverse cosine in radians for each element of @var{x}.\n\
 %! v = single ([0, pi/6, pi/4, pi/3, pi/2, 2*pi/3, 3*pi/4, 5*pi/6, pi]);
 %! assert (acos (x), v, sqrt (eps ("single")));
 
+## Test values on either side of branch cut
+%!test
+%! rval = 0;
+%! ival = 1.31695789692481635;
+%! obs = acos ([2, 2-i*eps, 2+i*eps]);
+%! exp = [rval + ival*i, rval + ival*i, rval - ival*i];
+%! assert (obs, exp, 2*eps);
+%! rval = pi;
+%! obs = acos ([-2, -2-i*eps, -2+i*eps]);
+%! exp = [rval - ival*i, rval + ival*i, rval - ival*i];
+%! assert (obs, exp, 2*eps);
+%! assert (acos ([2 0]),  [ival*i, pi/2], 2*eps);
+%! assert (acos ([2 0i]), [ival*i, pi/2], 2*eps);
+
 %!error acos ()
 %!error acos (1, 2)
 */
 
 DEFUN (acosh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} acosh (@var{x})\n\
 Compute the inverse hyperbolic cosine for each element of @var{x}.\n\
 @seealso{cosh}\n\
@@ -140,19 +157,31 @@ Compute the inverse hyperbolic cosine for each element of @var{x}.\n\
 %! v = [0, pi/2*i, pi*i, pi/2*i];
 %! assert (acosh (x), v, sqrt (eps));
 
+%!test
+%! re = 2.99822295029797;
+%! im = pi/2;
+%! assert (acosh (-10i), re - i*im);
+
 %!test
 %! x = single ([1, 0, -1, 0]);
 %! v = single ([0, pi/2*i, pi*i, pi/2*i]);
 %! assert (acosh (x), v, sqrt (eps ("single")));
 
+%!test
+%! re = single (2.99822295029797);
+%! im = single (pi/2);
+%! assert (acosh (single (10i)), re + i*im, 5*eps ("single"));
+%! assert (acosh (single (-10i)), re - i*im, 5*eps ("single"));
+
 %!error acosh ()
 %!error acosh (1, 2)
 */
 
 DEFUN (angle, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} angle (@var{z})\n\
-See arg.\n\
+See @code{arg}.\n\
+@seealso{arg}\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -165,10 +194,12 @@ See arg.\n\
 }
 
 DEFUN (arg, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn  {Mapping Function} {} arg (@var{z})\n\
 @deftypefnx {Mapping Function} {} angle (@var{z})\n\
-Compute the argument of @var{z}, defined as,\n\
+Compute the argument, i.e., angle of @var{z}.\n\
+\n\
+This is defined as,\n\
 @tex\n\
 $\\theta = atan2 (y, x),$\n\
 @end tex\n\
@@ -185,6 +216,7 @@ arg (3 + 4i)\n\
      @result{} 0.92730\n\
 @end group\n\
 @end example\n\
+@seealso{abs}\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -220,7 +252,7 @@ arg (3 + 4i)\n\
 */
 
 DEFUN (asin, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} asin (@var{x})\n\
 Compute the inverse sine in radians for each element of @var{x}.\n\
 @seealso{sin, asind}\n\
@@ -236,19 +268,39 @@ Compute the inverse sine in radians for each element of @var{x}.\n\
 }
 
 /*
-%!test
+%!shared rt2, rt3
 %! rt2 = sqrt (2);
 %! rt3 = sqrt (3);
+
+%!test
 %! x = [0, 1/2, rt2/2, rt3/2, 1, rt3/2, rt2/2, 1/2, 0];
 %! v = [0, pi/6, pi/4, pi/3, pi/2, pi/3, pi/4, pi/6, 0];
-%! assert (all (abs (asin (x) - v) < sqrt (eps)));
+%! assert (asin (x), v, sqrt (eps));
+
+%!test
+%! x = single ([0, 1/2, rt2/2, rt3/2, 1, rt3/2, rt2/2, 1/2, 0]);
+%! v = single ([0, pi/6, pi/4, pi/3, pi/2, pi/3, pi/4, pi/6, 0]);
+%! assert (asin (x), v, sqrt (eps ("single")));
+
+## Test values on either side of branch cut
+%!test
+%! rval = pi/2;
+%! ival = 1.31695789692481635;
+%! obs = asin ([2, 2-i*eps, 2+i*eps]);
+%! exp = [rval - ival*i, rval - ival*i, rval + ival*i];
+%! assert (obs, exp, 2*eps);
+%! obs = asin ([-2, -2-i*eps, -2+i*eps]);
+%! exp = [-rval + ival*i, -rval - ival*i, -rval + ival*i];
+%! assert (obs, exp, 2*eps);
+%! assert (asin ([2 0]),  [rval - ival*i, 0], 2*eps);
+%! assert (asin ([2 0i]), [rval - ival*i, 0], 2*eps);
 
 %!error asin ()
 %!error asin (1, 2)
 */
 
 DEFUN (asinh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} asinh (@var{x})\n\
 Compute the inverse hyperbolic sine for each element of @var{x}.\n\
 @seealso{sinh}\n\
@@ -279,7 +331,7 @@ Compute the inverse hyperbolic sine for each element of @var{x}.\n\
 */
 
 DEFUN (atan, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} atan (@var{x})\n\
 Compute the inverse tangent in radians for each element of @var{x}.\n\
 @seealso{tan, atand}\n\
@@ -314,7 +366,7 @@ Compute the inverse tangent in radians for each element of @var{x}.\n\
 */
 
 DEFUN (atanh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} atanh (@var{x})\n\
 Compute the inverse hyperbolic tangent for each element of @var{x}.\n\
 @seealso{tanh}\n\
@@ -345,9 +397,10 @@ Compute the inverse hyperbolic tangent for each element of @var{x}.\n\
 */
 
 DEFUN (cbrt, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} cbrt (@var{x})\n\
 Compute the real cube root of each element of @var{x}.\n\
+\n\
 Unlike @code{@var{x}^(1/3)}, the result will be negative if @var{x} is\n\
 negative.\n\
 @seealso{nthroot}\n\
@@ -377,11 +430,14 @@ negative.\n\
 */
 
 DEFUN (ceil, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} ceil (@var{x})\n\
-Return the smallest integer not less than @var{x}.  This is equivalent to\n\
-rounding towards positive infinity.  If @var{x} is\n\
-complex, return @code{ceil (real (@var{x})) + ceil (imag (@var{x})) * I}.\n\
+Return the smallest integer not less than @var{x}.\n\
+\n\
+This is equivalent to rounding towards positive infinity.\n\
+\n\
+If @var{x} is complex, return\n\
+@code{ceil (real (@var{x})) + ceil (imag (@var{x})) * I}.\n\
 \n\
 @example\n\
 @group\n\
@@ -419,9 +475,11 @@ ceil ([-2.7, 2.7])\n\
 */
 
 DEFUN (conj, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} conj (@var{z})\n\
-Return the complex conjugate of @var{z}, defined as\n\
+Return the complex conjugate of @var{z}.\n\
+\n\
+The complex conjugate is defined as\n\
 @tex\n\
 $\\bar{z} = x - iy$.\n\
 @end tex\n\
@@ -458,7 +516,7 @@ $\\bar{z} = x - iy$.\n\
 */
 
 DEFUN (cos, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} cos (@var{x})\n\
 Compute the cosine for each element of @var{x} in radians.\n\
 @seealso{acos, cosd, cosh}\n\
@@ -495,7 +553,7 @@ Compute the cosine for each element of @var{x} in radians.\n\
 */
 
 DEFUN (cosh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} cosh (@var{x})\n\
 Compute the hyperbolic cosine for each element of @var{x}.\n\
 @seealso{acosh, sinh, tanh}\n\
@@ -526,9 +584,11 @@ Compute the hyperbolic cosine for each element of @var{x}.\n\
 */
 
 DEFUN (erf, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erf (@var{z})\n\
-Compute the error function,\n\
+Compute the error function.\n\
+\n\
+The error function is defined as\n\
 @tex\n\
 $$\n\
  {\\rm erf} (z) = {2 \\over \\sqrt{\\pi}}\\int_0^z e^{-t^2} dt\n\
@@ -596,9 +656,11 @@ erf (z) = --------- *  | e^(-t^2) dt\n\
 */
 
 DEFUN (erfinv, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erfinv (@var{x})\n\
-Compute the inverse error function, i.e., @var{y} such that\n\
+Compute the inverse error function.\n\
+\n\
+The inverse error function is defined such that\n\
 \n\
 @example\n\
 erf (@var{y}) == @var{x}\n\
@@ -634,9 +696,11 @@ erf (@var{y}) == @var{x}\n\
 */
 
 DEFUN (erfcinv, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erfcinv (@var{x})\n\
-Compute the inverse complementary error function, i.e., @var{y} such that\n\
+Compute the inverse complementary error function.\n\
+\n\
+The inverse complementary error function is defined such that\n\
 \n\
 @example\n\
 erfc (@var{y}) == @var{x}\n\
@@ -672,9 +736,11 @@ erfc (@var{y}) == @var{x}\n\
 */
 
 DEFUN (erfc, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erfc (@var{z})\n\
-Compute the complementary error function,\n\
+Compute the complementary error function.\n\
+\n\
+The complementary error function is defined as\n\
 @tex\n\
 $1 - {\\rm erf} (z)$.\n\
 @end tex\n\
@@ -703,9 +769,11 @@ $1 - {\\rm erf} (z)$.\n\
 */
 
 DEFUN (erfcx, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erfcx (@var{z})\n\
-Compute the scaled complementary error function,\n\
+Compute the scaled complementary error function.\n\
+\n\
+The scaled complementary error function is defined as\n\
 @tex\n\
 $$\n\
  e^{z^2} {\\rm erfc} (z) \\equiv e^{z^2} (1 - {\\rm erf} (z))\n\
@@ -746,12 +814,14 @@ exp (z^2) * erfc (z)\n\
 */
 
 DEFUN (erfi, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} erfi (@var{z})\n\
-Compute the imaginary error function,\n\
+Compute the imaginary error function.\n\
+\n\
+The imaginary error function is defined as\n\
 @tex\n\
 $$\n\
- -i {\\rm erf} (iz) \n\
+ -i {\\rm erf} (iz)\n\
 $$\n\
 @end tex\n\
 @ifnottex\n\
@@ -784,9 +854,11 @@ $$\n\
 */
 
 DEFUN (dawson, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} dawson (@var{z})\n\
-Compute the Dawson (scaled imaginary error) function,\n\
+Compute the Dawson (scaled imaginary error) function.\n\
+\n\
+The Dawson function is defined as\n\
 @tex\n\
 $$\n\
  {\\sqrt{\\pi} \\over 2} e^{-z^2} {\\rm erfi} (z) \\equiv -i {\\sqrt{\\pi} \\over 2} e^{-z^2} {\\rm erf} (iz)\n\
@@ -824,7 +896,7 @@ $$\n\
 */
 
 DEFUN (exp, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} exp (@var{x})\n\
 Compute\n\
 @tex\n\
@@ -833,8 +905,9 @@ $e^{x}$\n\
 @ifnottex\n\
 @code{e^x}\n\
 @end ifnottex\n\
-for each element of @var{x}.  To compute the matrix\n\
-exponential, see @ref{Linear Algebra}.\n\
+for each element of @var{x}.\n\
+\n\
+To compute the matrix exponential, see @ref{Linear Algebra}.\n\
 @seealso{log}\n\
 @end deftypefn")
 {
@@ -861,7 +934,7 @@ exponential, see @ref{Linear Algebra}.\n\
 */
 
 DEFUN (expm1, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} expm1 (@var{x})\n\
 Compute\n\
 @tex\n\
@@ -894,16 +967,16 @@ accurately in the neighborhood of zero.\n\
 */
 
 DEFUN (isfinite, args, ,
-    "-*- texinfo -*-\n\
-@deftypefn  {Mapping Function} {} isfinite (@var{x})\n\
-@deftypefnx {Mapping Function} {} finite (@var{x})\n\
+       "-*- texinfo -*-\n\
+@deftypefn {Mapping Function} {} isfinite (@var{x})\n\
 Return a logical array which is true where the elements of @var{x} are\n\
 finite values and false where they are not.\n\
+\n\
 For example:\n\
 \n\
 @example\n\
 @group\n\
-finite ([13, Inf, NA, NaN])\n\
+isfinite ([13, Inf, NA, NaN])\n\
      @result{} [ 1, 0, 0, 0 ]\n\
 @end group\n\
 @end example\n\
@@ -920,23 +993,24 @@ finite ([13, Inf, NA, NaN])\n\
 }
 
 /*
-%!assert (!finite (Inf))
-%!assert (!finite (NaN))
-%!assert (finite (rand (1,10)))
+%!assert (!isfinite (Inf))
+%!assert (!isfinite (NaN))
+%!assert (isfinite (rand (1,10)))
 
-%!assert (!finite (single (Inf)))
-%!assert (!finite (single (NaN)))
-%!assert (finite (single (rand (1,10))))
+%!assert (!isfinite (single (Inf)))
+%!assert (!isfinite (single (NaN)))
+%!assert (isfinite (single (rand (1,10))))
 
-%!error finite ()
-%!error finite (1, 2)
+%!error isfinite ()
+%!error isfinite (1, 2)
 */
 
 DEFUN (fix, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} fix (@var{x})\n\
-Truncate fractional portion of @var{x} and return the integer portion.  This\n\
-is equivalent to rounding towards zero.  If @var{x} is complex, return\n\
+Truncate fractional portion of @var{x} and return the integer portion.\n\
+\n\
+This is equivalent to rounding towards zero.  If @var{x} is complex, return\n\
 @code{fix (real (@var{x})) + fix (imag (@var{x})) * I}.\n\
 \n\
 @example\n\
@@ -968,10 +1042,11 @@ fix ([-2.7, 2.7])\n\
 */
 
 DEFUN (floor, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} floor (@var{x})\n\
-Return the largest integer not greater than @var{x}.  This is equivalent to\n\
-rounding towards negative infinity.  If @var{x} is\n\
+Return the largest integer not greater than @var{x}.\n\
+\n\
+This is equivalent to rounding towards negative infinity.  If @var{x} is\n\
 complex, return @code{floor (real (@var{x})) + floor (imag (@var{x})) * I}.\n\
 \n\
 @example\n\
@@ -1003,9 +1078,11 @@ floor ([-2.7, 2.7])\n\
 */
 
 DEFUN (gamma, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} gamma (@var{z})\n\
-Compute the Gamma function,\n\
+Compute the Gamma function.\n\
+\n\
+The Gamma function is defined as\n\
 @tex\n\
 $$\n\
  \\Gamma (z) = \\int_0^\\infty t^{z-1} e^{-t} dt.\n\
@@ -1024,7 +1101,13 @@ gamma (z) = | t^(z-1) exp (-t) dt.\n\
 @end example\n\
 \n\
 @end ifnottex\n\
-@seealso{gammainc, lgamma}\n\
+\n\
+Programming Note: The gamma function can grow quite large even for small\n\
+input values.  In many cases it may be preferable to use the natural\n\
+logarithm of the gamma function (@code{gammaln}) in calculations to minimize\n\
+loss of precision.  The final result is then\n\
+@code{exp (@var{result_using_gammaln}).}\n\
+@seealso{gammainc, gammaln, factorial}\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -1056,8 +1139,9 @@ gamma (z) = | t^(z-1) exp (-t) dt.\n\
 %! assert (gamma (x), v, sqrt (eps ("single")));
 
 %!test
-%! x = [-1, 0, 1, Inf];
-%! v = [Inf, Inf, 1, Inf];
+%! ## Test exceptional values
+%! x = [-Inf, -1, -0, 0, 1, Inf, NaN];
+%! v = [Inf, Inf, -Inf, Inf, 1, Inf, NaN];
 %! assert (gamma (x), v);
 %! assert (gamma (single (x)), single (v));
 
@@ -1066,7 +1150,7 @@ gamma (z) = | t^(z-1) exp (-t) dt.\n\
 */
 
 DEFUN (imag, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} imag (@var{z})\n\
 Return the imaginary part of @var{z} as a real number.\n\
 @seealso{real, conj}\n\
@@ -1097,11 +1181,12 @@ Return the imaginary part of @var{z} as a real number.\n\
 */
 
 DEFUNX ("isalnum", Fisalnum, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isalnum (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
-letters or digits and false where they are not.  This is equivalent to\n\
-(@code{isalpha (@var{s}) | isdigit (@var{s})}).\n\
+letters or digits and false where they are not.\n\
+\n\
+This is equivalent to (@code{isalpha (@var{s}) | isdigit (@var{s})}).\n\
 @seealso{isalpha, isdigit, ispunct, isspace, iscntrl}\n\
 @end deftypefn")
 {
@@ -1128,11 +1213,12 @@ letters or digits and false where they are not.  This is equivalent to\n\
 */
 
 DEFUNX ("isalpha", Fisalpha, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isalpha (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
-letters and false where they are not.  This is equivalent to\n\
-(@code{islower (@var{s}) | isupper (@var{s})}).\n\
+letters and false where they are not.\n\
+\n\
+This is equivalent to (@code{islower (@var{s}) | isupper (@var{s})}).\n\
 @seealso{isdigit, ispunct, isspace, iscntrl, isalnum, islower, isupper}\n\
 @end deftypefn")
 {
@@ -1158,7 +1244,7 @@ letters and false where they are not.  This is equivalent to\n\
 */
 
 DEFUNX ("isascii", Fisascii, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isascii (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 ASCII characters (in the range 0 to 127 decimal) and false where they are\n\
@@ -1185,7 +1271,7 @@ not.\n\
 */
 
 DEFUNX ("iscntrl", Fiscntrl, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} iscntrl (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 control characters and false where they are not.\n\
@@ -1214,7 +1300,7 @@ control characters and false where they are not.\n\
 */
 
 DEFUNX ("isdigit", Fisdigit, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isdigit (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 decimal digits (0-9) and false where they are not.\n\
@@ -1242,10 +1328,11 @@ decimal digits (0-9) and false where they are not.\n\
 */
 
 DEFUN (isinf, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isinf (@var{x})\n\
 Return a logical array which is true where the elements of @var{x} are\n\
-are infinite and false where they are not.\n\
+infinite and false where they are not.\n\
+\n\
 For example:\n\
 \n\
 @example\n\
@@ -1284,7 +1371,7 @@ isinf ([13, Inf, NA, NaN])\n\
 */
 
 DEFUNX ("isgraph", Fisgraph, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isgraph (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 printable characters (but not the space character) and false where they are\n\
@@ -1313,7 +1400,7 @@ not.\n\
 */
 
 DEFUNX ("islower", Fislower, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} islower (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 lowercase letters and false where they are not.\n\
@@ -1341,10 +1428,11 @@ lowercase letters and false where they are not.\n\
 */
 
 DEFUN (isna, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isna (@var{x})\n\
 Return a logical array which is true where the elements of @var{x} are\n\
 NA (missing) values and false where they are not.\n\
+\n\
 For example:\n\
 \n\
 @example\n\
@@ -1383,10 +1471,11 @@ isna ([13, Inf, NA, NaN])\n\
 */
 
 DEFUN (isnan, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isnan (@var{x})\n\
 Return a logical array which is true where the elements of @var{x} are\n\
 NaN values and false where they are not.\n\
+\n\
 NA values are also considered NaN values.  For example:\n\
 \n\
 @example\n\
@@ -1425,7 +1514,7 @@ isnan ([13, Inf, NA, NaN])\n\
 */
 
 DEFUNX ("isprint", Fisprint, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isprint (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 printable characters (including the space character) and false where they\n\
@@ -1454,7 +1543,7 @@ are not.\n\
 */
 
 DEFUNX ("ispunct", Fispunct, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} ispunct (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 punctuation characters and false where they are not.\n\
@@ -1485,7 +1574,7 @@ punctuation characters and false where they are not.\n\
 */
 
 DEFUNX ("isspace", Fisspace, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isspace (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 whitespace characters (space, formfeed, newline, carriage return, tab, and\n\
@@ -1514,7 +1603,7 @@ vertical tab) and false where they are not.\n\
 */
 
 DEFUNX ("isupper", Fisupper, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isupper (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 uppercase letters and false where they are not.\n\
@@ -1542,7 +1631,7 @@ uppercase letters and false where they are not.\n\
 */
 
 DEFUNX ("isxdigit", Fisxdigit, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} isxdigit (@var{s})\n\
 Return a logical array which is true where the elements of @var{s} are\n\
 hexadecimal digits (0-9 and @nospell{a-fA-F}).\n\
@@ -1572,9 +1661,9 @@ hexadecimal digits (0-9 and @nospell{a-fA-F}).\n\
 */
 
 DEFUN (lgamma, args, ,
-    "-*- texinfo -*-\n\
-@deftypefn  {Mapping Function} {} lgamma (@var{x})\n\
-@deftypefnx {Mapping Function} {} gammaln (@var{x})\n\
+       "-*- texinfo -*-\n\
+@deftypefn  {Mapping Function} {} gammaln (@var{x})\n\
+@deftypefnx {Mapping Function} {} lgamma (@var{x})\n\
 Return the natural logarithm of the gamma function of @var{x}.\n\
 @seealso{gamma, gammainc}\n\
 @end deftypefn")
@@ -1591,34 +1680,34 @@ Return the natural logarithm of the gamma function of @var{x}.\n\
 /*
 %!test
 %! a = -1i*sqrt (-1/(6.4187*6.4187));
-%! assert (lgamma (a), lgamma (real (a)));
+%! assert (gammaln (a), gammaln (real (a)));
 
 %!test
 %! x = [.5, 1, 1.5, 2, 3, 4, 5];
 %! v = [sqrt(pi), 1, .5*sqrt(pi), 1, 2, 6, 24];
-%! assert (lgamma (x), log (v), sqrt (eps))
+%! assert (gammaln (x), log (v), sqrt (eps))
 
 %!test
 %! a = single (-1i*sqrt (-1/(6.4187*6.4187)));
-%! assert (lgamma (a), lgamma (real (a)));
+%! assert (gammaln (a), gammaln (real (a)));
 
 %!test
 %! x = single ([.5, 1, 1.5, 2, 3, 4, 5]);
 %! v = single ([sqrt(pi), 1, .5*sqrt(pi), 1, 2, 6, 24]);
-%! assert (lgamma (x), log (v), sqrt (eps ("single")))
+%! assert (gammaln (x), log (v), sqrt (eps ("single")))
 
 %!test
 %! x = [-1, 0, 1, Inf];
 %! v = [Inf, Inf, 0, Inf];
-%! assert (lgamma (x), v);
-%! assert (lgamma (single (x)), single (v));
+%! assert (gammaln (x), v);
+%! assert (gammaln (single (x)), single (v));
 
-%!error lgamma ()
-%!error lgamma (1,2)
+%!error gammaln ()
+%!error gammaln (1,2)
 */
 
 DEFUN (log, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} log (@var{x})\n\
 Compute the natural logarithm,\n\
 @tex\n\
@@ -1627,8 +1716,9 @@ $\\ln{(x)},$\n\
 @ifnottex\n\
 @code{ln (@var{x})},\n\
 @end ifnottex\n\
-for each element of @var{x}.  To compute the\n\
-matrix logarithm, see @ref{Linear Algebra}.\n\
+for each element of @var{x}.\n\
+\n\
+To compute the matrix logarithm, see @ref{Linear Algebra}.\n\
 @seealso{exp, log1p, log2, log10, logspace}\n\
 @end deftypefn")
 {
@@ -1653,7 +1743,7 @@ matrix logarithm, see @ref{Linear Algebra}.\n\
 */
 
 DEFUN (log10, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} log10 (@var{x})\n\
 Compute the base-10 logarithm of each element of @var{x}.\n\
 @seealso{log, log2, logspace, exp}\n\
@@ -1677,7 +1767,7 @@ Compute the base-10 logarithm of each element of @var{x}.\n\
 */
 
 DEFUN (log1p, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} log1p (@var{x})\n\
 Compute\n\
 @tex\n\
@@ -1708,7 +1798,7 @@ accurately in the neighborhood of zero.\n\
 */
 
 DEFUN (real, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} real (@var{z})\n\
 Return the real part of @var{z}.\n\
 @seealso{imag, conj}\n\
@@ -1739,9 +1829,11 @@ Return the real part of @var{z}.\n\
 */
 
 DEFUN (round, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} round (@var{x})\n\
-Return the integer nearest to @var{x}.  If @var{x} is complex, return\n\
+Return the integer nearest to @var{x}.\n\
+\n\
+If @var{x} is complex, return\n\
 @code{round (real (@var{x})) + round (imag (@var{x})) * I}.  If there\n\
 are two nearest integers, return the one further away from zero.\n\
 \n\
@@ -1785,10 +1877,12 @@ round ([-2.7, 2.7])\n\
 */
 
 DEFUN (roundb, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} roundb (@var{x})\n\
 Return the integer nearest to @var{x}.  If there are two nearest\n\
-integers, return the even one (banker's rounding).  If @var{x} is complex,\n\
+integers, return the even one (banker's rounding).\n\
+\n\
+If @var{x} is complex,\n\
 return @code{roundb (real (@var{x})) + roundb (imag (@var{x})) * I}.\n\
 @seealso{round}\n\
 @end deftypefn")
@@ -1826,9 +1920,11 @@ return @code{roundb (real (@var{x})) + roundb (imag (@var{x})) * I}.\n\
 */
 
 DEFUN (sign, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} sign (@var{x})\n\
-Compute the @dfn{signum} function, which is defined as\n\
+Compute the @dfn{signum} function.\n\
+\n\
+This is defined as\n\
 @tex\n\
 $$\n\
 {\\rm sign} (@var{x}) = \\cases{1,&$x>0$;\\cr 0,&$x=0$;\\cr -1,&$x<0$.\\cr}\n\
@@ -1848,8 +1944,7 @@ sign (x) =  0, x = 0;\n\
 \n\
 For complex arguments, @code{sign} returns @code{x ./ abs (@var{x})}.\n\
 \n\
-Note that @code{sign (-0.0)} is 0.\n\
-Although IEEE 754 floating point\n\
+Note that @code{sign (-0.0)} is 0.  Although IEEE 754 floating point\n\
 allows zero to be signed, 0.0 and -0.0 compare equal.  If you must test\n\
 whether zero is signed, use the @code{signbit} function.\n\
 @seealso{signbit}\n\
@@ -1880,12 +1975,14 @@ whether zero is signed, use the @code{signbit} function.\n\
 */
 
 DEFUNX ("signbit", Fsignbit, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} signbit (@var{x})\n\
-Return logical true if the value of @var{x} has its sign bit set.\n\
-Otherwise return logical false.  This behavior is consistent with the other\n\
-logical functions.  See@ref{Logical Values}.  The behavior differs from the\n\
-C language function which returns non-zero if the sign bit is set.\n\
+Return logical true if the value of @var{x} has its sign bit set and false\n\
+otherwise.\n\
+\n\
+This behavior is consistent with the other logical functions.\n\
+See @ref{Logical Values}.  The behavior differs from the C language function\n\
+which returns nonzero if the sign bit is set.\n\
 \n\
 This is not the same as @code{x < 0.0}, because IEEE 754 floating point\n\
 allows zero to be signed.  The comparison @code{-0.0 < 0.0} is false,\n\
@@ -1894,9 +1991,11 @@ but @code{signbit (-0.0)} will return a nonzero value.\n\
 @end deftypefn")
 {
   octave_value retval;
-  if (args.length () == 1) {
-    retval = args(0).xsignbit ();
-    retval = (retval != 0); }
+  if (args.length () == 1)
+    {
+      retval = args(0).xsignbit ();
+      retval = (retval != 0);
+    }
   else
     print_usage ();
 
@@ -1919,7 +2018,7 @@ but @code{signbit (-0.0)} will return a nonzero value.\n\
 */
 
 DEFUN (sin, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} sin (@var{x})\n\
 Compute the sine for each element of @var{x} in radians.\n\
 @seealso{asin, sind, sinh}\n\
@@ -1954,7 +2053,7 @@ Compute the sine for each element of @var{x} in radians.\n\
 */
 
 DEFUN (sinh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} sinh (@var{x})\n\
 Compute the hyperbolic sine for each element of @var{x}.\n\
 @seealso{asinh, cosh, tanh}\n\
@@ -1985,11 +2084,13 @@ Compute the hyperbolic sine for each element of @var{x}.\n\
 */
 
 DEFUN (sqrt, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} sqrt (@var{x})\n\
-Compute the square root of each element of @var{x}.  If @var{x} is negative,\n\
-a complex result is returned.  To compute the matrix square root, see\n\
-@ref{Linear Algebra}.\n\
+Compute the square root of each element of @var{x}.\n\
+\n\
+If @var{x} is negative, a complex result is returned.\n\
+\n\
+To compute the matrix square root, see @ref{Linear Algebra}.\n\
 @seealso{realsqrt, nthroot}\n\
 @end deftypefn")
 {
@@ -2018,7 +2119,7 @@ a complex result is returned.  To compute the matrix square root, see\n\
 */
 
 DEFUN (tan, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} tan (@var{z})\n\
 Compute the tangent for each element of @var{x} in radians.\n\
 @seealso{atan, tand, tanh}\n\
@@ -2053,7 +2154,7 @@ Compute the tangent for each element of @var{x} in radians.\n\
 */
 
 DEFUN (tanh, args, ,
-    "-*- texinfo -*-\n\
+       "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} tanh (@var{x})\n\
 Compute hyperbolic tangent for each element of @var{x}.\n\
 @seealso{atanh, sinh, cosh}\n\
@@ -2084,9 +2185,11 @@ Compute hyperbolic tangent for each element of @var{x}.\n\
 */
 
 DEFUNX ("toascii", Ftoascii, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn {Mapping Function} {} toascii (@var{s})\n\
-Return ASCII representation of @var{s} in a matrix.  For example:\n\
+Return ASCII representation of @var{s} in a matrix.\n\
+\n\
+For example:\n\
 \n\
 @example\n\
 @group\n\
@@ -2120,12 +2223,14 @@ toascii (\"ASCII\")\n\
 */
 
 DEFUNX ("tolower", Ftolower, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn  {Mapping Function} {} tolower (@var{s})\n\
 @deftypefnx {Mapping Function} {} lower (@var{s})\n\
 Return a copy of the string or cell string @var{s}, with each uppercase\n\
 character replaced by the corresponding lowercase one; non-alphabetic\n\
-characters are left unchanged.  For example:\n\
+characters are left unchanged.\n\
+\n\
+For example:\n\
 \n\
 @example\n\
 @group\n\
@@ -2153,8 +2258,17 @@ DEFALIAS (lower, tolower);
 %!assert (tolower ({"ABC", "DEF", {"GHI", {"JKL"}}}), {"abc", "def", {"ghi", {"jkl"}}})
 %!assert (tolower (["ABC"; "DEF"]), ["abc"; "def"])
 %!assert (tolower ({["ABC"; "DEF"]}), {["abc";"def"]})
-%!assert (tolower (68), "d")
-%!assert (tolower ({[68, 68; 68, 68]}), {["dd";"dd"]})
+%!assert (tolower (68), 68)
+%!assert (tolower ({[68, 68; 68, 68]}), {[68, 68; 68, 68]})
+%!test
+%! classes = {@char, @double, @single, ...
+%!            @int8, @int16, @int32, @int64, ...
+%!            @uint8, @uint16, @uint32, @uint64};
+%! for i = 1:numel (classes)
+%!   cls = classes{i};
+%!   assert (class (tolower (cls (97))), class (cls (97)));
+%!   assert (class (tolower (cls ([98, 99]))), class (cls ([98, 99])));
+%! endfor
 %!test
 %! a(3,3,3,3) = "D";
 %! assert (tolower (a)(3,3,3,3), "d");
@@ -2171,12 +2285,14 @@ DEFALIAS (lower, tolower);
 */
 
 DEFUNX ("toupper", Ftoupper, args, ,
-    "-*- texinfo -*-\n\
+        "-*- texinfo -*-\n\
 @deftypefn  {Mapping Function} {} toupper (@var{s})\n\
 @deftypefnx {Mapping Function} {} upper (@var{s})\n\
 Return a copy of the string or cell string @var{s}, with each lowercase\n\
 character replaced by the corresponding uppercase one; non-alphabetic\n\
-characters are left unchanged.  For example:\n\
+characters are left unchanged.\n\
+\n\
+For example:\n\
 \n\
 @example\n\
 @group\n\
@@ -2204,8 +2320,17 @@ DEFALIAS (upper, toupper);
 %!assert (toupper ({"abc", "def", {"ghi", {"jkl"}}}), {"ABC", "DEF", {"GHI", {"JKL"}}})
 %!assert (toupper (["abc"; "def"]), ["ABC"; "DEF"])
 %!assert (toupper ({["abc"; "def"]}), {["ABC";"DEF"]})
-%!assert (toupper (100), "D")
-%!assert (toupper ({[100, 100; 100, 100]}), {["DD";"DD"]})
+%!assert (toupper (100), 100)
+%!assert (toupper ({[100, 100; 100, 100]}), {[100, 100; 100, 100]})
+%!test
+%! classes = {@char, @double, @single, ...
+%!            @int8, @int16, @int32, @int64, ...
+%!            @uint8, @uint16, @uint32, @uint64};
+%! for i = 1:numel (classes)
+%!   cls = classes{i};
+%!   assert (class (toupper (cls (97))), class (cls (97)));
+%!   assert (class (toupper (cls ([98, 99]))), class (cls ([98, 99])));
+%! endfor
 %!test
 %! a(3,3,3,3) = "d";
 %! assert (toupper (a)(3,3,3,3), "D");
@@ -2222,4 +2347,3 @@ DEFALIAS (upper, toupper);
 
 DEFALIAS (gammaln, lgamma);
 
-DEFALIAS (finite, isfinite);
