@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2012 Jason Riedy, Jaroslav Hajek
+Copyright (C) 2009-2015 Jason Riedy, Jaroslav Hajek
 
 This file is part of Octave.
 
@@ -24,6 +24,15 @@ along with Octave; see the file COPYING.  If not, see
 #include <config.h>
 #endif
 
+#include "mx-cm-s.h"
+#include "mx-s-cm.h"
+
+#include "mx-dm-cs.h"
+#include "mx-cs-dm.h"
+
+#include "mx-m-cs.h"
+#include "mx-cs-m.h"
+
 #include "gripes.h"
 #include "oct-obj.h"
 #include "ov.h"
@@ -41,7 +50,8 @@ along with Octave; see the file COPYING.  If not, see
 
 DEFBINOP (mul_dm_scm, diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -54,7 +64,8 @@ DEFBINOP (mul_dm_scm, diag_matrix, sparse_complex_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      SparseComplexMatrix ret = v1.diag_matrix_value () * v2.sparse_complex_matrix_value ();
+      SparseComplexMatrix ret = v1.diag_matrix_value () *
+                                v2.sparse_complex_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -64,7 +75,8 @@ DEFBINOP (mul_dm_scm, diag_matrix, sparse_complex_matrix)
 
 DEFBINOP (mul_cdm_sm, complex_diag_matrix, sparse_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -77,7 +89,8 @@ DEFBINOP (mul_cdm_sm, complex_diag_matrix, sparse_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      SparseComplexMatrix ret = v1.complex_diag_matrix_value () * v2.sparse_matrix_value ();
+      SparseComplexMatrix ret = v1.complex_diag_matrix_value () *
+                                v2.sparse_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -87,7 +100,8 @@ DEFBINOP (mul_cdm_sm, complex_diag_matrix, sparse_matrix)
 
 DEFBINOP (mul_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -100,7 +114,8 @@ DEFBINOP (mul_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      SparseComplexMatrix ret = v1.complex_diag_matrix_value () * v2.sparse_complex_matrix_value ();
+      SparseComplexMatrix ret = v1.complex_diag_matrix_value () *
+                                v2.sparse_complex_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -134,13 +149,15 @@ DEFBINOP (ldiv_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
                    const octave_sparse_complex_matrix&);
 
   MatrixType typ = v2.matrix_type ();
-  return xleftdiv (v1.complex_diag_matrix_value (), v2.sparse_complex_matrix_value (),
+  return xleftdiv (v1.complex_diag_matrix_value (),
+                   v2.sparse_complex_matrix_value (),
                    typ);
 }
 
 DEFBINOP (add_dm_scm, diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -156,7 +173,8 @@ DEFBINOP (add_dm_scm, diag_matrix, sparse_complex_matrix)
 
 DEFBINOP (add_cdm_sm, complex_diag_matrix, sparse_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -172,7 +190,8 @@ DEFBINOP (add_cdm_sm, complex_diag_matrix, sparse_matrix)
 
 DEFBINOP (add_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -188,7 +207,8 @@ DEFBINOP (add_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
 
 DEFBINOP (sub_dm_scm, diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -204,7 +224,8 @@ DEFBINOP (sub_dm_scm, diag_matrix, sparse_complex_matrix)
 
 DEFBINOP (sub_cdm_sm, complex_diag_matrix, sparse_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -220,7 +241,8 @@ DEFBINOP (sub_cdm_sm, complex_diag_matrix, sparse_matrix)
 
 DEFBINOP (sub_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
 {
-  CAST_BINOP_ARGS (const octave_complex_diag_matrix&, const octave_sparse_complex_matrix&);
+  CAST_BINOP_ARGS (const octave_complex_diag_matrix&,
+                   const octave_sparse_complex_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -238,7 +260,8 @@ DEFBINOP (sub_cdm_scm, complex_diag_matrix, sparse_complex_matrix)
 
 DEFBINOP (mul_scm_dm, sparse_complex_matrix, diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_diag_matrix&);
 
   if (v1.rows () == 1 && v1.columns () == 1)
     // If v1 is a scalar in disguise, return a diagonal matrix rather than
@@ -251,7 +274,8 @@ DEFBINOP (mul_scm_dm, sparse_complex_matrix, diag_matrix)
   else
     {
       MatrixType typ = v1.matrix_type ();
-      SparseComplexMatrix ret = v1.sparse_complex_matrix_value () * v2.diag_matrix_value ();
+      SparseComplexMatrix ret = v1.sparse_complex_matrix_value () *
+                                v2.diag_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -261,7 +285,8 @@ DEFBINOP (mul_scm_dm, sparse_complex_matrix, diag_matrix)
 
 DEFBINOP (mul_sm_cdm, sparse_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v1.rows () == 1 && v1.columns () == 1)
     // If v1 is a scalar in disguise, return a diagonal matrix rather than
@@ -274,7 +299,8 @@ DEFBINOP (mul_sm_cdm, sparse_matrix, complex_diag_matrix)
   else
     {
       MatrixType typ = v1.matrix_type ();
-      SparseComplexMatrix ret = v1.sparse_matrix_value () * v2.complex_diag_matrix_value ();
+      SparseComplexMatrix ret = v1.sparse_matrix_value () *
+                                v2.complex_diag_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -284,7 +310,8 @@ DEFBINOP (mul_sm_cdm, sparse_matrix, complex_diag_matrix)
 
 DEFBINOP (mul_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v1.rows () == 1 && v1.columns () == 1)
     // If v1 is a scalar in disguise, return a diagonal matrix rather than
@@ -304,7 +331,8 @@ DEFBINOP (mul_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
   else
     {
       MatrixType typ = v1.matrix_type ();
-      SparseComplexMatrix ret = v1.sparse_complex_matrix_value () * v2.complex_diag_matrix_value ();
+      SparseComplexMatrix ret = v1.sparse_complex_matrix_value () *
+                                v2.complex_diag_matrix_value ();
       octave_value out = octave_value (ret);
       typ.mark_as_unsymmetric ();
       out.matrix_type (typ);
@@ -314,7 +342,8 @@ DEFBINOP (mul_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 
 DEFBINOP (div_scm_dm, sparse_complex_matrix, diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     {
@@ -328,13 +357,15 @@ DEFBINOP (div_scm_dm, sparse_complex_matrix, diag_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      return xdiv (v1.sparse_complex_matrix_value (), v2.diag_matrix_value (), typ);
+      return xdiv (v1.sparse_complex_matrix_value (),
+                   v2.diag_matrix_value (), typ);
     }
 }
 
 DEFBINOP (div_sm_cdm, sparse_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     {
@@ -348,13 +379,15 @@ DEFBINOP (div_sm_cdm, sparse_matrix, complex_diag_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      return xdiv (v1.sparse_matrix_value (), v2.complex_diag_matrix_value (), typ);
+      return xdiv (v1.sparse_matrix_value (),
+                   v2.complex_diag_matrix_value (), typ);
     }
 }
 
 DEFBINOP (div_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     {
@@ -368,13 +401,15 @@ DEFBINOP (div_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
   else
     {
       MatrixType typ = v2.matrix_type ();
-      return xdiv (v1.sparse_complex_matrix_value (), v2.complex_diag_matrix_value (), typ);
+      return xdiv (v1.sparse_complex_matrix_value (),
+                   v2.complex_diag_matrix_value (), typ);
     }
 }
 
 DEFBINOP (add_sm_cdm, sparse_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -390,7 +425,8 @@ DEFBINOP (add_sm_cdm, sparse_matrix, complex_diag_matrix)
 
 DEFBINOP (add_scm_dm, sparse_complex_matrix, diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -406,7 +442,8 @@ DEFBINOP (add_scm_dm, sparse_complex_matrix, diag_matrix)
 
 DEFBINOP (add_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -422,7 +459,8 @@ DEFBINOP (add_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 
 DEFBINOP (sub_sm_cdm, sparse_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -438,7 +476,8 @@ DEFBINOP (sub_sm_cdm, sparse_matrix, complex_diag_matrix)
 
 DEFBINOP (sub_scm_dm, sparse_complex_matrix, diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -454,7 +493,8 @@ DEFBINOP (sub_scm_dm, sparse_complex_matrix, diag_matrix)
 
 DEFBINOP (sub_scm_cdm, sparse_complex_matrix, complex_diag_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&, const octave_complex_diag_matrix&);
+  CAST_BINOP_ARGS (const octave_sparse_complex_matrix&,
+                   const octave_complex_diag_matrix&);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     // If v2 is a scalar in disguise, return a diagonal matrix rather than
@@ -475,37 +515,52 @@ install_dm_scm_ops (void)
                  mul_dm_scm);
   INSTALL_BINOP (op_mul, octave_complex_diag_matrix, octave_sparse_matrix,
                  mul_cdm_sm);
-  INSTALL_BINOP (op_mul, octave_complex_diag_matrix, octave_sparse_complex_matrix,
-                 mul_cdm_scm);
-  INSTALL_BINOP (op_ldiv, octave_diag_matrix, octave_sparse_complex_matrix, ldiv_dm_scm);
-  INSTALL_BINOP (op_ldiv, octave_complex_diag_matrix, octave_sparse_matrix, ldiv_cdm_sm);
-  INSTALL_BINOP (op_ldiv, octave_complex_diag_matrix, octave_sparse_complex_matrix,
-                 ldiv_cdm_scm);
+  INSTALL_BINOP (op_mul, octave_complex_diag_matrix,
+                 octave_sparse_complex_matrix, mul_cdm_scm);
+  INSTALL_BINOP (op_ldiv, octave_diag_matrix, octave_sparse_complex_matrix,
+                 ldiv_dm_scm);
+  INSTALL_BINOP (op_ldiv, octave_complex_diag_matrix, octave_sparse_matrix,
+                 ldiv_cdm_sm);
+  INSTALL_BINOP (op_ldiv, octave_complex_diag_matrix,
+                 octave_sparse_complex_matrix, ldiv_cdm_scm);
 
-  INSTALL_BINOP (op_add, octave_diag_matrix, octave_sparse_complex_matrix, add_dm_scm);
-  INSTALL_BINOP (op_add, octave_complex_diag_matrix, octave_sparse_matrix, add_cdm_sm);
-  INSTALL_BINOP (op_add, octave_complex_diag_matrix, octave_sparse_complex_matrix,
-                 add_cdm_scm);
-  INSTALL_BINOP (op_sub, octave_diag_matrix, octave_sparse_complex_matrix, sub_dm_scm);
-  INSTALL_BINOP (op_sub, octave_complex_diag_matrix, octave_sparse_matrix, sub_cdm_sm);
-  INSTALL_BINOP (op_sub, octave_complex_diag_matrix, octave_sparse_complex_matrix,
-                 sub_cdm_scm);
+  INSTALL_BINOP (op_add, octave_diag_matrix, octave_sparse_complex_matrix,
+                 add_dm_scm);
+  INSTALL_BINOP (op_add, octave_complex_diag_matrix, octave_sparse_matrix,
+                 add_cdm_sm);
+  INSTALL_BINOP (op_add, octave_complex_diag_matrix,
+                 octave_sparse_complex_matrix, add_cdm_scm);
+  INSTALL_BINOP (op_sub, octave_diag_matrix, octave_sparse_complex_matrix,
+                 sub_dm_scm);
+  INSTALL_BINOP (op_sub, octave_complex_diag_matrix, octave_sparse_matrix,
+                 sub_cdm_sm);
+  INSTALL_BINOP (op_sub, octave_complex_diag_matrix,
+                 octave_sparse_complex_matrix, sub_cdm_scm);
 
   INSTALL_BINOP (op_mul, octave_sparse_complex_matrix, octave_diag_matrix,
                  mul_scm_dm);
   INSTALL_BINOP (op_mul, octave_sparse_matrix, octave_complex_diag_matrix,
                  mul_sm_cdm);
-  INSTALL_BINOP (op_mul, octave_sparse_complex_matrix, octave_complex_diag_matrix,
-                 mul_scm_cdm);
+  INSTALL_BINOP (op_mul, octave_sparse_complex_matrix,
+                 octave_complex_diag_matrix, mul_scm_cdm);
 
-  INSTALL_BINOP (op_div, octave_sparse_complex_matrix, octave_diag_matrix, div_scm_dm);
-  INSTALL_BINOP (op_div, octave_sparse_matrix, octave_complex_diag_matrix, div_sm_cdm);
-  INSTALL_BINOP (op_div, octave_sparse_complex_matrix, octave_complex_diag_matrix, div_scm_cdm);
+  INSTALL_BINOP (op_div, octave_sparse_complex_matrix, octave_diag_matrix,
+                 div_scm_dm);
+  INSTALL_BINOP (op_div, octave_sparse_matrix, octave_complex_diag_matrix,
+                 div_sm_cdm);
+  INSTALL_BINOP (op_div, octave_sparse_complex_matrix,
+                 octave_complex_diag_matrix, div_scm_cdm);
 
-  INSTALL_BINOP (op_add, octave_sparse_complex_matrix, octave_diag_matrix, add_scm_dm);
-  INSTALL_BINOP (op_add, octave_sparse_matrix, octave_complex_diag_matrix, add_sm_cdm);
-  INSTALL_BINOP (op_add, octave_sparse_complex_matrix, octave_complex_diag_matrix, add_scm_cdm);
-  INSTALL_BINOP (op_sub, octave_sparse_complex_matrix, octave_diag_matrix, sub_scm_dm);
-  INSTALL_BINOP (op_sub, octave_sparse_matrix, octave_complex_diag_matrix, sub_sm_cdm);
-  INSTALL_BINOP (op_sub, octave_sparse_complex_matrix, octave_complex_diag_matrix, sub_scm_cdm);
+  INSTALL_BINOP (op_add, octave_sparse_complex_matrix, octave_diag_matrix,
+                 add_scm_dm);
+  INSTALL_BINOP (op_add, octave_sparse_matrix, octave_complex_diag_matrix,
+                 add_sm_cdm);
+  INSTALL_BINOP (op_add, octave_sparse_complex_matrix,
+                 octave_complex_diag_matrix, add_scm_cdm);
+  INSTALL_BINOP (op_sub, octave_sparse_complex_matrix, octave_diag_matrix,
+                 sub_scm_dm);
+  INSTALL_BINOP (op_sub, octave_sparse_matrix, octave_complex_diag_matrix,
+                 sub_sm_cdm);
+  INSTALL_BINOP (op_sub, octave_sparse_complex_matrix,
+                 octave_complex_diag_matrix, sub_scm_cdm);
 }
