@@ -1,4 +1,4 @@
-## Copyright (C) 2001-2012 Paul Kienzle
+## Copyright (C) 2001-2015 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -20,15 +20,17 @@
 ## @deftypefn  {Function File} {} interpft (@var{x}, @var{n})
 ## @deftypefnx {Function File} {} interpft (@var{x}, @var{n}, @var{dim})
 ##
-## Fourier interpolation.  If @var{x} is a vector, then @var{x} is
-## resampled with @var{n} points.  The data in @var{x} is assumed to be
-## equispaced.  If @var{x} is a matrix or an N-dimensional array, the
-## interpolation is performed on each column of @var{x}.  If @var{dim} is
-## specified, then interpolate along the dimension @var{dim}.
+## Fourier interpolation.
 ##
-## @code{interpft} assumes that the interpolated function is periodic,
-## and so assumptions are made about the endpoints of the interpolation.
+## If @var{x} is a vector then @var{x} is resampled with @var{n} points.  The
+## data in @var{x} is assumed to be equispaced.  If @var{x} is a matrix or an
+## N-dimensional array, the interpolation is performed on each column of
+## @var{x}.
 ##
+## If @var{dim} is specified, then interpolate along the dimension @var{dim}.
+##
+## @code{interpft} assumes that the interpolated function is periodic, and so
+## assumptions are made about the endpoints of the interpolation.
 ## @seealso{interp1}
 ## @end deftypefn
 
@@ -120,19 +122,19 @@ endfunction
 %!assert (interpft (y', n), y', 20*eps);
 %!assert (interpft ([y,y],n), [y,y], 20*eps);
 
-%% Test case with complex input from bug #39566
+## Test case with complex input from bug #39566
 %!test
 %! x = (1 + j) * [1:4]';
 %! y = ifft ([15 + 15*j; -6; -1.5 - 1.5*j; 0; -1.5 - 1.5*j; -6*j]);
 %! assert (interpft (x, 6), y, 10*eps);
 
-%% Test for correct spectral symmetry with even/odd lengths
+## Test for correct spectral symmetry with even/odd lengths
 %!assert (max (abs (imag (interpft ([1:8], 20)))), 0, 20*eps);
 %!assert (max (abs (imag (interpft ([1:8], 21)))), 0, 21*eps);
 %!assert (max (abs (imag (interpft ([1:9], 20)))), 0, 20*eps);
 %!assert (max (abs (imag (interpft ([1:9], 21)))), 0, 21*eps);
 
-%% Test input validation
+## Test input validation
 %!error interpft ()
 %!error interpft (1)
 %!error interpft (1,2,3)
