@@ -20,15 +20,15 @@
 ## @deftypefn  {Function File} {@var{jary} =} javaArray (@var{classname}, @var{sz})
 ## @deftypefnx {Function File} {@var{jary} =} javaArray (@var{classname}, @var{m}, @var{n}, @dots{})
 ##
-## Create a Java array of size @var{sz} with elements of class
-## @var{classname}.  @var{classname} may be a Java object representing a class
-## or a string containing the fully qualified class name.  The size of
-## the object may also be specified with individual integer arguments
-## @var{m}, @var{n}, etc.
+## Create a Java array of size @var{sz} with elements of class @var{classname}.
 ##
-## The generated array is uninitialized.  All elements are set to null
-## if @var{classname} is a reference type, or to a default value (usually 0)
-## if @var{classname} is a primitive type.
+## @var{classname} may be a Java object representing a class or a string
+## containing the fully qualified class name.  The size of the object may
+## also be specified with individual integer arguments @var{m}, @var{n}, etc.
+##
+## The generated array is uninitialized.  All elements are set to null if
+## @var{classname} is a reference type, or to a default value (usually 0) if
+## @var{classname} is a primitive type.
 ##
 ## Sample code:
 ##
