@@ -1,4 +1,4 @@
-## Copyright (C) 1994-2012 John W. Eaton
+## Copyright (C) 1994-2015 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -67,7 +67,7 @@ function y = conv (a, b, shape = "full")
 
   ## Use shortest vector as the coefficent vector to filter.
   if (la > lb)
-    [a, b] = deal (b, a);  # Swap vectors 
+    [a, b] = deal (b, a);  # Swap vectors
     lb = la;
   endif
   x = b;
@@ -137,7 +137,7 @@ endfunction
 %!assert (conv (b,a,"valid"), zeros (1,0))
 
 
-%% Test input validation
+## Test input validation
 %!error conv (1)
 %!error conv (1,2,3,4)
 %!error <A and B must be vectors> conv ([1, 2; 3, 4], 3)
