@@ -1,4 +1,4 @@
-## Copyright (C) 2001-2012 Paul Kienzle
+## Copyright (C) 2001-2015 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -19,9 +19,10 @@
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {@var{y} =} filter2 (@var{b}, @var{x})
 ## @deftypefnx {Function File} {@var{y} =} filter2 (@var{b}, @var{x}, @var{shape})
-## Apply the 2-D FIR filter @var{b} to @var{x}.  If the argument
-## @var{shape} is specified, return an array of the desired shape.
-## Possible values are:
+## Apply the 2-D FIR filter @var{b} to @var{x}.
+##
+## If the argument @var{shape} is specified, return an array of the desired
+## shape.  Possible values are:
 ##
 ## @table @asis
 ## @item @qcode{"full"}
@@ -34,8 +35,8 @@
 ## trim @var{x} after filtering so edge effects are no included.
 ## @end table
 ##
-## Note this is just a variation on convolution, with the parameters
-## reversed and @var{b} rotated 180 degrees.
+## Note this is just a variation on convolution, with the parameters reversed
+## and @var{b} rotated 180 degrees.
 ## @seealso{conv2}
 ## @end deftypefn
 
