@@ -1,18 +1,20 @@
 ## Copyright (C) 2006 Sylvain Pelissier
-## Copyright (C) 2012 Carlo de Falco
+## Copyright (C) 2012-2015 Carlo de Falco
 ##
-## This program is free software; you can redistribute it and/or modify
+## This file is part of Octave.
+##
+## Octave is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
+## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful,
+## Octave is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## along with Octave; If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {@var{x} =} bicg (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{M1}, @var{M2}, @var{x0})
@@ -21,26 +23,25 @@
 ## Solve @code{A x = b} using the Bi-conjugate gradient iterative method.
 ##
 ## @itemize @minus
-## @item @var{rtol} is the relative tolerance, if not given
-## or set to [] the default value 1e-6 is used.
+## @item @var{rtol} is the relative tolerance, if not given or set to [] the
+## default value 1e-6 is used.
 ##
-## @item @var{maxit} the maximum number of outer iterations,
-## if not given or set to [] the default value
-## @code{min (20, numel (b))} is used.
+## @item @var{maxit} the maximum number of outer iterations, if not given or
+## set to [] the default value @code{min (20, numel (b))} is used.
 ##
-## @item @var{x0} the initial guess, if not given or set to []
-## the default value @code{zeros (size (b))} is used.
+## @item @var{x0} the initial guess, if not given or set to [] the default
+## value @code{zeros (size (b))} is used.
 ## @end itemize
 ##
-## @var{A} can be passed as a matrix or as a function handle or
-## inline function @code{f} such that @code{f(x, "notransp") = A*x}
-## and @code{f(x, "transp") = A'*x}.
+## @var{A} can be passed as a matrix or as a function handle or inline function
+## @code{f} such that @code{f(x, "notransp") = A*x} and
+## @code{f(x, "transp") = A'*x}.
 ##
-## The preconditioner @var{P} is given as @code{P = M1 * M2}.
-## Both @var{M1} and @var{M2} can be passed as a matrix or as
-## a function handle or inline function @code{g} such that
-## @code{g(x, "notransp") = M1 \ x} or @code{g(x, "notransp") = M2 \ x} and
-## @code{g(x, "transp") = M1' \ x} or @code{g(x, "transp") = M2' \ x}.
+## The preconditioner @var{P} is given as @code{P = M1 * M2}.  Both @var{M1}
+## and @var{M2} can be passed as a matrix or as a function handle or inline
+## function @code{g} such that @code{g(x, "notransp") = M1 \ x} or
+## @code{g(x, "notransp") = M2 \ x} and @code{g(x, "transp") = M1' \ x} or
+## @code{g(x, "transp") = M2' \ x}.
 ##
 ## If called with more than one output parameter
 ##
@@ -61,10 +62,11 @@
 ##
 ## @item @var{iter} is the number of iterations performed.
 ##
-## @item @var{resvec} is a vector containing the relative residual at each iteration.
+## @item @var{resvec} is a vector containing the relative residual at each
+## iteration.
 ## @end itemize
 ##
-## @seealso{bicgstab, cgs, gmres, pcg}
+## @seealso{bicgstab, cgs, gmres, pcg, qmr}
 ##
 ## @end deftypefn
 
@@ -79,15 +81,14 @@ function [x, flag, res1, k, resvec] = bicg (A, b, tol, maxit, M1, M2, x0)
       fun = str2func (A);
       Ax  = @(x) feval (fun, x, "notransp");
       Atx = @(x) feval (fun, x, "transp");
-    elseif (ismatrix (A))
+    elseif (isnumeric (A) && issquare (A))
       Ax  = @(x) A  * x;
       Atx = @(x) A' * x;
     elseif (isa (A, "function_handle"))
       Ax  = @(x) feval (A, x, "notransp");
       Atx = @(x) feval (A, x, "transp");
     else
-      error (["bicg: first argument is expected to " ...
-              "be a function or a square matrix"]);
+      error ("bicg: A must be a function or square matrix");
     endif
 
     if (nargin < 3 || isempty (tol))
@@ -96,6 +97,8 @@ function [x, flag, res1, k, resvec] = bicg (A, b, tol, maxit, M1, M2, x0)
 
     if (nargin < 4 || isempty (maxit))
       maxit = min (rows (b), 20);
+    else
+      maxit = fix (maxit);
     endif
 
     if (nargin < 5 || isempty (M1))
@@ -105,15 +108,14 @@ function [x, flag, res1, k, resvec] = bicg (A, b, tol, maxit, M1, M2, x0)
       fun = str2func (M1);
       M1m1x  = @(x) feval (fun, x, "notransp");
       M1tm1x = @(x) feval (fun, x, "transp");
-    elseif (ismatrix (M1))
+    elseif (isnumeric (M1) && ismatrix (M1))
       M1m1x  = @(x) M1  \ x;
       M1tm1x = @(x) M1' \ x;
     elseif (isa (M1, "function_handle"))
       M1m1x  = @(x) feval (M1, x, "notransp");
       M1tm1x = @(x) feval (M1, x, "transp");
     else
-      error (["bicg: preconditioner is expected to " ...
-              "be a function or matrix"]);
+      error ("bicg: preconditioner M1 must be a function or matrix");
     endif
 
     if (nargin < 6 || isempty (M2))
@@ -123,15 +125,14 @@ function [x, flag, res1, k, resvec] = bicg (A, b, tol, maxit, M1, M2, x0)
       fun = str2func (M2);
       M2m1x  = @(x) feval (fun, x, "notransp");
       M2tm1x = @(x) feval (fun, x, "transp");
-    elseif (ismatrix (M2))
+    elseif (isnumeric (M2) && ismatrix (M2))
       M2m1x  = @(x) M2  \ x;
       M2tm1x = @(x) M2' \ x;
     elseif (isa (M2, "function_handle"))
       M2m1x  = @(x) feval (M2, x, "notransp");
       M2tm1x = @(x) feval (M2, x, "transp");
     else
-      error (["bicg: preconditioner is expected to " ...
-              "be a function or matrix"]);
+      error ("bicg: preconditioner M2 must be a function or matrix");
     endif
 
     Pm1x  = @(x) M2m1x  (M1m1x (x));
