@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2012 Ivana Varekova
+## Copyright (C) 2005-2015 Ivana Varekova
 ##
 ## This file is part of Octave.
 ##
@@ -20,9 +20,10 @@
 ## @deftypefn  {Function File} {} etreeplot (@var{A})
 ## @deftypefnx {Function File} {} etreeplot (@var{A}, @var{node_style}, @var{edge_style})
 ## Plot the elimination tree of the matrix @var{A} or
-## @tcode{@var{A}+@var{A}'} if @var{A} in not symmetric.  The optional
-## parameters @var{node_style} and @var{edge_style} define the output
-## style.
+## @tcode{@var{A}+@var{A}'} if @var{A} in not symmetric.
+##
+## The optional parameters @var{node_style} and @var{edge_style} define the
+## output style.
 ## @seealso{treeplot, gplot}
 ## @end deftypefn
 
