@@ -1,4 +1,4 @@
-## Copyright (C) 2006-2012 David Bateman
+## Copyright (C) 2006-2015 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -24,8 +24,9 @@
 ## @deftypefnx {Function File} {[@var{u}, @var{s}, @var{v}] =} svds (@dots{})
 ## @deftypefnx {Function File} {[@var{u}, @var{s}, @var{v}, @var{flag}] =} svds (@dots{})
 ##
-## Find a few singular values of the matrix @var{A}.  The singular values
-## are calculated using
+## Find a few singular values of the matrix @var{A}.
+##
+## The singular values are calculated using
 ##
 ## @example
 ## @group
@@ -107,16 +108,16 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
     opts.disp = 0;
     opts.maxit = 300;
   else
-    if (!isstruct (opts))
+    if (! isstruct (opts))
       error ("svds: OPTS must be a structure");
     endif
-    if (!isfield (opts, "tol"))
+    if (! isfield (opts, "tol"))
       opts.tol = 0;  # use ARPACK default
     else
       opts.tol = opts.tol / root2;
     endif
     if (isfield (opts, "v0"))
-      if (!isvector (opts.v0) || (length (opts.v0) != sum (size (A))))
+      if (! isvector (opts.v0) || (length (opts.v0) != sum (size (A))))
         error ("svds: OPTS.v0 must be a vector with rows(A)+columns(A) entries");
       endif
     endif
@@ -143,7 +144,7 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
   endif
   ## Must initialize variable value, otherwise it may appear to interpreter
   ## that code is trying to call flag() colormap function.
-  flag = 0;  
+  flag = 0;
 
   if (max_a == 0)
     s = zeros (k, 1);  # special case of zero matrix
@@ -160,7 +161,7 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
     ## Call to eigs is always a symmetric matrix by construction
     b_opts.issym = true;
     b_sigma = sigma;
-    if (!ischar (b_sigma))
+    if (! ischar (b_sigma))
       b_sigma = b_sigma / max_a;
     endif
 
@@ -169,7 +170,7 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
       ## The eigenvalues returns by eigs for sigma=0 are symmetric about 0.
       ## As we are only interested in the positive eigenvalues, we have to
       ## double k and then throw out the k negative eigenvalues.
-      ## Separately, if sigma is non-zero, but smaller than the smallest
+      ## Separately, if sigma is nonzero, but smaller than the smallest
       ## singular value, ARPACK may not return k eigenvalues. However, as
       ## computation scales with k we'd like to avoid doubling k for all
       ## scalar values of sigma.
@@ -199,6 +200,14 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
     ## less than or equal to zero to within some tolerance scaled by the
     ## norm since if we don't we might end up with too many singular
     ## values.
+    if (b_sigma == 0)
+      if (sum (s>0) < k)
+        ## It may happen that the number of positive s is less than k.
+        ## In this case, take -s (if s in an eigenvalue, so is -s),
+        ## flipped upside-down.
+        s = flipud (-s);
+      endif
+    endif
     tol = norma * opts.tol;
     ind = find (s > tol);
     if (length (ind) < k)
@@ -219,7 +228,7 @@ function [u, s, v, flag] = svds (A, k, sigma, opts)
 
     if (length (s) < k)
       warning ("returning fewer singular values than requested");
-      if (!ischar (sigma))
+      if (! ischar (sigma))
         warning ("try increasing the value of sigma");
       endif
     endif
@@ -276,8 +285,8 @@ endfunction
 %! [u2,s2,v2,flag] = svds (A,k,0,opts);
 %! s2 = diag (s2);
 %! assert (flag, !1);
-%! tol = 10 * eps() * norm(s2, 1);
-%! assert (s2, s(k:-1:1), tol);
+%! tol = 100 * eps() * norm(s2, 1);
+%! assert (s2, s(length(s2):-1:1), tol);
 %!
 %!testif HAVE_ARPACK, HAVE_UMFPACK
 %! idx = floor (n/2);
@@ -297,7 +306,7 @@ endfunction
 %!
 %!testif HAVE_ARPACK
 %! s = svds (speye (10));
-%! assert (s, ones (6, 1), 4*eps);
+%! assert (s, ones (6, 1), 8*eps);
 
 %!test
 %! ## Restore random number generator seeds at end of tests
