@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2013 Kurt Hornik
+## Copyright (C) 1995-2015 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -19,8 +19,9 @@
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {[@var{t}, @var{l_x}] =} table (@var{x})
 ## @deftypefnx {Function File} {[@var{t}, @var{l_x}, @var{l_y}] =} table (@var{x}, @var{y})
-## Create a contingency table @var{t} from data vectors.  The @var{l_x} and
-## @var{l_y} vectors are the corresponding levels.
+## Create a contingency table @var{t} from data vectors.
+##
+## The @var{l_x} and @var{l_y} vectors are the corresponding levels.
 ##
 ## Currently, only 1- and 2-dimensional tables are supported.
 ## @end deftypefn
@@ -35,7 +36,7 @@ function [t, v, w] = table (x, y)
   endif
 
   if (nargin == 1)
-    if (!isnumeric (x) || !isvector (x))
+    if (! isnumeric (x) || ! isvector (x))
       error ("table: X must be a numeric vector");
     endif
     v = unique (x);
@@ -61,7 +62,7 @@ function [t, v, w] = table (x, y)
 endfunction
 
 
-%% Test input validation
+## Test input validation
 %!error table ()
 %!error table (1, 2, 3)
 %!error table (ones (2))
