@@ -1,5 +1,5 @@
 ## Copyright (C) 2012 Rik Wehbring
-## Copyright (C) 1996-2012 Kurt Hornik
+## Copyright (C) 1996-2015 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -19,9 +19,9 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} discrete_pdf (@var{x}, @var{v}, @var{p})
-## For each element of @var{x}, compute the probability density function
-## (PDF) at @var{x} of a univariate discrete distribution which assumes
-## the values in @var{v} with probabilities @var{p}.
+## For each element of @var{x}, compute the probability density function (PDF)
+## at @var{x} of a univariate discrete distribution which assumes the values
+## in @var{v} with probabilities @var{p}.
 ## @end deftypefn
 
 ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
@@ -44,7 +44,7 @@ function pdf = discrete_pdf (x, v, p)
   endif
 
   ## Reshape and normalize probability vector.  Values not in table get 0 prob.
-  p = [0 ; p(:)/sum(p)];   
+  p = [0 ; p(:)/sum(p)];
 
   if (isa (x, "single") || isa (v, "single") || isa (p, "single"))
     pdf = NaN (size (x), "single");
@@ -52,7 +52,7 @@ function pdf = discrete_pdf (x, v, p)
     pdf = NaN (size (x));
   endif
 
-  k = !isnan (x);
+  k = ! isnan (x);
   [vs, vi] = sort (v(:));
   pdf(k) = p([0 ; vi](lookup (vs, x(k), 'm') + 1) + 1);
 
@@ -66,12 +66,12 @@ endfunction
 %! y = [0 0.1 0.1 0.1 0];
 %!assert (discrete_pdf ([x, NaN], v, p), [y, NaN], 5*eps)
 
-%% Test class of input preserved
+## Test class of input preserved
 %!assert (discrete_pdf (single ([x, NaN]), v, p), single ([y, NaN]), 5*eps ("single"))
 %!assert (discrete_pdf ([x, NaN], single (v), p), single ([y, NaN]), 5*eps ("single"))
 %!assert (discrete_pdf ([x, NaN], v, single (p)), single ([y, NaN]), 5*eps ("single"))
 
-%% Test input validation
+## Test input validation
 %!error discrete_pdf ()
 %!error discrete_pdf (1)
 %!error discrete_pdf (1,2)
